-- -*- coding: utf-8 -*- 
-- lcalc.lua
-- Made by JackDole

function help()
    print ("    ")
    print ("    lcalc <ausdruck>")
    print ("    ")
    print ("    math.abs (x)        Returns the absolute value of x.")
    print ("    math.acos (x)       Returns the arc cosine of x (in radians)")
    print ("    math.asin (x)       Returns the arc sine of x (in radians).")    
    print ("    math.atan (x)       Returns the arc tangent of x (in radians).") 
    print ("    math.atan2 (y, x)   Returns the arc tangent of y/x (in radians), but uses the signs of both parameters to find the quadrant of the result.")
    print ("                        (It also handles correctly the case of x being zero.) ")
    print ("    math.ceil (x)       Returns the smallest integer larger than or equal to x.") 
    print ("    math.cos (x)        Returns the cosine of x (assumed to be in radians). ")
    print ("    math.cosh (x)       Returns the hyperbolic cosine of x. ")
    print ("    math.deg (x)        Returns the angle x (given in radians) in degrees. ")
    print ("    math.exp (x)        Returns the value ex. ")
    print ("    math.floor (x)      Returns the largest integer smaller than or equal to x. ")
    print ("    math.fmod (x, y)    Returns the remainder of the division of x by y that rounds the quotient towards zero. ")
    print ("    math.frexp (x)      Returns m and e such that x = m2e, e is an integer and the absolute value of m is in the range [0.5, 1)")
    print ("                        (or zero when x is zero). ")
    print ("    math.huge           The value HUGE_VAL, a value larger than or equal to any other numerical value. ")
    print ("    math.ldexp (m, e)   Returns m2e (e should be an integer). ")
    print ("    math.log (x)        Returns the natural logarithm of x. ")
    print ("    math.log10 (x)      Returns the base-10 logarithm of x. ")
    print ("    math.max (x, ...)   Returns the maximum value among its arguments. ")
    print ("    math.min (x, ...)   Returns the minimum value among its arguments. ")
    print ("    math.modf (x)       Returns two numbers, the integral part of x and the fractional part of x. ")
    print ("    math.pi             The value of pi. ")
    print ("    math.pow (x, y)     Returns xy. (You can also use the expression x^y to compute this value.) ")
    print ("    math.rad (x)        Returns the angle x (given in degrees) in radians. ")
    print ("    math.random ([m [, n]]) This function is an interface to the simple pseudo-random generator function rand ")
    print ("                        provided by ANSI C. (No guarantees can be given for its statistical properties.) ")
    print ("                        When called without arguments, returns a uniform pseudo-random real number in the range [0,1). ")
    print ("                        When called with an integer number m, math.random returns a uniform pseudo-random integer in the range [1, m]. ")
    print ("                        When called with two integer numbers m and n, math.random returns a uniform pseudo-random integer in the range [m, n]. ")
    print ("    math.randomseed (x) Sets x as the 'seed' for the pseudo-random generator: equal seeds produce equal sequences of numbers. ")
    print ("    math.sin (x)        Returns the sine of x (assumed to be in radians). ")
    print ("    math.sinh (x)       Returns the hyperbolic sine of x. ")
    print ("    math.sqrt (x)       Returns the square root of x. (You can also use the expression x^0.5 to compute this value.) ")
    print ("    math.tan (x)        Returns the tangent of x (assumed to be in radians). ")
    print ("    math.tanh (x)       Returns the hyperbolic tangent of x.")
end

function getcommandline()
    local expr = ""
    for i=1, table.getn(arg) do
        a=arg[i]
        expr = expr .. a
    end
    return string.gsub (expr, " ", "")
end

function calcIt()
    local expr = arg[1]
    if expr ~= nil then expr=string.lower(expr) end
    if expr == nil or expr == "-h" or expr == "/h" or expr == "-help" or expr == "/help" or expr == "-?" or expr == "/?" or expr == "?" then
        help()
        return
    end
    
    expr = getcommandline()
    expr = addMath(expr)
    if not expr or expr == "" then return end
    local f, msg = loadstring("return "..expr)
    if not f then
        --print(">Calculator: cannot evaluate selection") return
        print(nil) return
    end
    print (tostring(f()))
end

function addMath (expr)
    expr=string.lower(expr)
    expr=string.gsub (expr, "math.",    "")    
    expr=string.gsub (expr, "acos",     "math.01")
    expr=string.gsub (expr, "asin",     "math.02")
    expr=string.gsub (expr, "atan2",    "math.03")
    expr=string.gsub (expr, "atan",     "math.04")
    expr=string.gsub (expr, "cosh",     "math.05")
    expr=string.gsub (expr, "sinh",     "math.06")
    expr=string.gsub (expr, "tanh",     "math.07")
    expr=string.gsub (expr, "log10",    "math.08")
    expr=string.gsub (expr, "randomseed", "math.09")
    expr=string.gsub (expr, "frexp",    "math.0a")
    expr=string.gsub (expr, "idexp",    "math.0b")
    expr=string.gsub (expr, "ceiling",  "math.0c")
    expr=string.gsub (expr, "fmod",     "math.0d")
    expr=string.gsub (expr, "modf",     "math.0e")
    
    expr=string.gsub (expr, "abs",      "math.abs")
    expr=string.gsub (expr, "ceil",     "math.ceil")
    expr=string.gsub (expr, "cos",      "math.cos")
    expr=string.gsub (expr, "deg",      "math.deg")
    expr=string.gsub (expr, "exp",      "math.exp")
    expr=string.gsub (expr, "floor",    "math.floor")
    expr=string.gsub (expr, "int",      "math.floor")
    expr=string.gsub (expr, "mod",      "math.fmod")
    expr=string.gsub (expr, "huge",     "math.huge")
    expr=string.gsub (expr, "log",      "math.log")
    expr=string.gsub (expr, "max",      "math.max")
    expr=string.gsub (expr, "min",      "math.min")
    expr=string.gsub (expr, "pi",       "math.pi")
    expr=string.gsub (expr, "pow",      "math.pow")
    expr=string.gsub (expr, "rad",      "math.rad")
    expr=string.gsub (expr, "random",   "math.random")
    expr=string.gsub (expr, "sin",      "math.sin")
    expr=string.gsub (expr, "sqrt",     "math.sqrt")
    expr=string.gsub (expr, "tan",      "math.tan")
    
    expr=string.gsub (expr, "math.01", "math.acos")
    expr=string.gsub (expr, "math.02", "math.asin")
    expr=string.gsub (expr, "math.03", "math.atan2")
    expr=string.gsub (expr, "math.04", "math.atan")
    expr=string.gsub (expr, "math.05", "math.cosh")
    expr=string.gsub (expr, "math.06", "math.sinh")
    expr=string.gsub (expr, "math.07", "math.tanh")
    expr=string.gsub (expr, "math.08", "math.log10")
    expr=string.gsub (expr, "math.09", "math.randomseed")
    expr=string.gsub (expr, "math.0a", "math.frexp")
    expr=string.gsub (expr, "math.0b", "math.idexp")
    expr=string.gsub (expr, "math.0c", "math.ceil")
    expr=string.gsub (expr, "math.0d", "math.fmod")
    expr=string.gsub (expr, "math.0e", "math.modf")
    
    return expr
end

--help()
calcIt()
